@@ -53,22 +53,18 @@ WACodeRequest::WACodeRequest(QString cc, QString in, QString method,
 #endif
 
     if (mcc.length() < 3)
-        mcc = QString(3-mcc.length(),QChar('0')) + mcc;
+        mcc = mcc.rightJustified(3, '0');
 
     if (mnc.length() < 3)
-        mnc = QString(3-mnc.length(),QChar('0')) + mnc;
+        mnc = mnc.rightJustified(3, '0');
 
     addParam("cc", cc);
     addParam("in", in);
-    addParam("lc", country.isEmpty() ?  "ZZ" : country);
-    addParam("lg", language.isEmpty() ? "zz" : language);
-    addParam("mcc", "000");
-    addParam("mnc", "000");
+    addParam("lc", country.isEmpty() ?  "GB" : country);
+    addParam("lg", language.isEmpty() ? "en" : language);
     addParam("sim_mcc", mcc);
     addParam("sim_mnc", mnc);
     addParam("method", method);
-    addParam("network_radio_type", "1");
-    addParam("reason","self-send-jailbroken");
     addParam("token", Utilities::getToken(in));
     addParam("id",id);
 }
